#!/bin/bash
# Christian Dieterich Tue Feb 12 09:14:03 CET 2013
# Modified Tue Apr 29 14:25:39 CEST 2014
# Modified Tue Apr 29 18:35:13 CEST 2014
# Modified Wed Apr 30 17:19:18 CEST 2014

# Provides a selection of bash functions that return specific parts of a
# standard NEMO file name:
#
# setup_period_yyyymmdd_yyyymmdd_gridtype.nc
# setup_period_yyyymmdd_yyyymmdd_gridtype_0000.nc
#
# The setup part may contain underscores.
# The gridtype part must be 6 characters long.
# Optionally a 4 digit subdomain may be present at the end.

function nemofilename {
    filename=$(basename $* .nc)
    echo $filename
}
function nemosubdomain {
    filename=$(nemofilename $*)
    tmpindex=$((${#filename}-4))
    subdomain=${filename:$tmpindex:4}
    tmppattern='^[0-9]+$'
    if ! [[ $subdomain =~ $tmppattern ]]; then
        subdomain=
    fi
    echo $subdomain
}
function nemogridtype {
#    filename=$(nemofilename $*)
#    IFS='_';  read -ra tmparray <<< "$filename"
#    tmparray=$(echo $filename | tr "_" "\n")
#    tmpindex=$((${#tmparray[@]}-2))
#    tmpindex1=$((${#tmparray[@]}-1))
#    gridtype=${tmparray[$tmpindex]}'_'${tmparray[$tmpindex1]}
    filename=$(nemofilename $*)
    subdomain=$(nemosubdomain $*)
    if ! [[ -z $subdomain ]]; then
        tmpindex=$((${#filename}-11))
    else
        tmpindex=$((${#filename}-6))
    fi
    gridtype=${filename:$tmpindex:6}
    echo $gridtype
}
function nemomastername {
    filename=$(nemofilename $*)
    subdomain=$(nemosubdomain $*)
    if ! [[ -z $subdomain ]]; then
        tmpindex=$((${#filename}-5))
    else
        tmpindex=$((${#filename}))
    fi
    mastername=${filename:0:$tmpindex}
    echo $mastername
}
function nemoshortname {
    filename=$(nemofilename $*)
    subdomain=$(nemosubdomain $*)
    if ! [[ -z $subdomain ]]; then
        tmpindex=$((${#filename}-12))
    else
        tmpindex=$((${#filename}-7))
    fi
    shortname=${filename:0:$tmpindex}
    echo $shortname
}
function nemoperiod {
#    filename=$(nemofilename $*)
#    IFS='_';  read -ra tmparray <<< "$filename"
#    tmparray=$(echo $filename | tr "_" "\n")
#    tmpindex=$((${#tmparray[@]}-5))
#    period=${tmparray[$tmpindex]}
    shortname=$(nemoshortname $*)
    tmparray=${shortname//[^_]}
    tmpindex=$((${#tmparray}-3+2))
    period=$(echo $shortname | cut -d'_' -f$tmpindex)
    echo $period
}
function nemofirstdate {
#    filename=$(nemofilename $*)
#    IFS='_';  read -ra tmparray <<< "$filename"
#    tmparray=$(echo $filename | tr "_" "\n")
#    tmpindex=$((${#tmparray[@]}-4))
#    firstdate=${tmparray[$tmpindex]}
    shortname=$(nemoshortname $*)
    tmparray=${shortname//[^_]}
    tmpindex=$((${#tmparray}-3+3))
    firstdate=$(echo $shortname | cut -d'_' -f$tmpindex)
    echo $firstdate
}
function nemolastdate {
#    filename=$(nemofilename $*)
#    IFS='_';  read -ra tmparray <<< "$filename"
#    tmparray=$(echo $filename | tr "_" "\n")
#    tmpindex=$((${#tmparray[@]}-3))
#    lastdate=${tmparray[$tmpindex]}
    shortname=$(nemoshortname $*)
    tmparray=${shortname//[^_]}
    tmpindex=$((${#tmparray}-3+4))
    lastdate=$(echo $shortname | cut -d'_' -f$tmpindex)
    echo $lastdate
}
function nemofilestamp {
    period=$(nemoperiod $*)
    firstdate=$(nemofirstdate $*)
    lastdate=$(nemolastdate $*)
    gridtype=$(nemogridtype $*)
    filestamp=$period'_'$firstdate'_'$lastdate'_'$gridtype
    echo $filestamp
}
function nemosetup {
#    filename=$(nemofilename $*)
#    filestamp='_'$(nemofilestamp $*)
#    setup=$(echo $filename | sed "s/$filestamp//g")
    mastername=$(nemomastername $*)
    filestamp=$(nemofilestamp $*)
    tmpindex=$((${#mastername}-${#filestamp}-1))
    setup=${mastername:0:($tmpindex)}
    echo $setup
}
function nemotimestamp {
    firstdate=$(nemofirstdate $*)
    lastdate=$(nemolastdate $*)
    timestamp=$firstdate'_'$lastdate
    echo $timestamp
}
function nemofirstyear {
#    firstyear=$(echo $(nemofirstdate $*) | cut -c1-4)
    firstdate=$(nemofirstdate $*)
    firstyear=${firstdate:0:4}
    echo $firstyear
}
function nemolastyear {
#    lastyear=$(echo $(nemolastdate $*) | cut -c1-4)
    lastdate=$(nemolastdate $*)
    lastyear=${lastdate:0:4}
    echo $lastyear
}
function nemofirstmmdd {
#    firstmmdd=$(echo $(nemofirstdate $*) | cut -c5-8)
    firstdate=$(nemofirstdate $*)
    firstmmdd=${firstdate:4:4}
    echo $firstmmdd
}
function nemolastmmdd {
#    lastmmdd=$(echo $(nemolastdate $*) | cut -c5-8)
    lastdate=$(nemolastdate $*)
    lastmmdd=${lastdate:4:4}
    echo $lastmmdd
}

