#!/bin/bash

. ./scripts/nemonomen.sh

tmpfile=$(mktemp --suffix=.nc)
tmpfile2=$(mktemp --suffix=.nc)

while IFS='' read -r line; do
    varid=$(echo $line | cut -f1 -d',')
    code=$(echo $line | cut -f2 -d',')
    level=$(echo $line | cut -f3 -d',')
    name=$(echo $line | cut -f4 -d',')
    units=$(echo $line | cut -f5 -d',')
    lname=$(echo $line | cut -f6 -d',')
    sname=$(echo $line | cut -f7 -d',')
    echo $varid, $code, $level, $name, $units, $lname, $sname

    for file in $*; do
        # construct output file according to CMIP5 conventions
        year=$(nemofirstyear $file)
        period='Omon'
        model='RCA4-NEMO-ECHAM5'
        experiment='sresa1b'
        ensemble='r3i1p1'
        firstmonth='01'
        lastmonth='12'
        outfile=$name'_'$period'_'$model'_'$experiment'_'$ensemble'_'$year$firstmonth'-'$year$lastmonth'.nc'
        echo $file $outfile

        cdo -f nc4 copy $file $tmpfile2 # transform to netcdf

        ncks -O -v $varid $tmpfile2 $tmpfile # pick variable
        if [ $? -eq 0 ]; then

            ncrename -O -v $varid,$name $tmpfile $tmpfile2 # rename variable
            ncatted -O -a long_name,$name,o,c,"$lname" \
                    -a standard_name,$name,o,c,"$sname" \
                    -a units,$name,o,c,"$units" \
                    $tmpfile2 $tmpfile # add attributes
            nccopy -d 1 $tmpfile $outfile # compress netcdf file

        fi

    done

done < mapping.ocn.txt

