#!/bin/bash

tmpfile=$(mktemp --suffix=.nc)
tmpfile2=$(mktemp --suffix=.nc)

extra='rotated_pole'

while IFS='' read -r line; do
    varid=$(echo $line | cut -f1 -d',')
    code=$(echo $line | cut -f2 -d',')
    level=$(echo $line | cut -f3 -d',')
    name=$(echo $line | cut -f4 -d',')
    units=$(echo $line | cut -f5 -d',')
    lname=$(echo $line | cut -f6 -d',')
    sname=$(echo $line | cut -f7 -d',')
    echo $varid, $code, $level, $name, $units, $lname, $sname

    for file in $*; do
        # construct output file according to CMIP5 conventions
        year=$(basename $file | cut -c3-6)
        month=$(basename $file | cut -c7-8)
        period='Amon'
        model='RCA4-NEMO-ECHAM5'
        experiment='sresa1b'
        ensemble='r3i1p1'
        firstmonth='01'
        lastmonth='12'
        outfile=$name'_'$period'_'$model'_'$experiment'_'$ensemble'_'$year$month'-'$year$month'.nc'
        echo $file $outfile

        cdo -f nc4 selcode,$code -sellevel,$level $file $tmpfile2 # pick code and level and transform to netcdf

        ncks -O -v $varid,$extra $tmpfile2 $tmpfile # pick variable
        if [ $? -eq 0 ]; then

            ncrename -O -v $varid,$name $tmpfile $tmpfile2 # rename variable
            ncatted -O -a long_name,$name,o,c,"$lname" \
                    -a standard_name,$name,o,c,"$sname" \
                    -a units,$name,o,c,"$units" \
                    $tmpfile2 $tmpfile # add attributes
            ncwa -O -a height $tmpfile $tmpfile2 # reduce dimension height
            ncks -O -x -v height $tmpfile2 $outfile # delete dimension height

        fi

    done

done < mapping.uvas.txt

rm -f $tmpfile $tmpfile2

